@@ -40,6 +40,7 @@
 #include "chrome/common/logging_chrome.h"
 #include "chrome/common/url_constants.h"
 #include "chrome/gpu/chrome_content_gpu_client.h"
+#include "chrome/plugin/chrome_content_plugin_client.h"
 #include "chrome/renderer/chrome_content_renderer_client.h"
 #include "chrome/utility/chrome_content_utility_client.h"
 #include "components/component_updater/component_updater_paths.h"
@@ -186,6 +187,8 @@ base::LazyInstance<ChromeContentRendererClient>::DestructorAtExit
     g_chrome_content_renderer_client = LAZY_INSTANCE_INITIALIZER;
 base::LazyInstance<ChromeContentUtilityClient>::DestructorAtExit
     g_chrome_content_utility_client = LAZY_INSTANCE_INITIALIZER;
+base::LazyInstance<ChromeContentPluginClient>::DestructorAtExit
+    g_chrome_content_plugin_client = LAZY_INSTANCE_INITIALIZER;
 #endif
 
 extern int NaClMain(const content::MainFunctionParams&);
@@ -284,7 +287,8 @@ void SetUpExtendedCrashReporting(bool is_browser_process) {
 void AdjustLinuxOOMScore(const std::string& process_type) {
   int score = -1;
 
-  if (process_type == switches::kPpapiPluginProcess) {
+  if (process_type == switches::kPpapiPluginProcess ||
+      process_type == switches::kPluginProcess) {
     score = content::kPluginOomScore;
   } else if (process_type == switches::kUtilityProcess ||
              process_type == switches::kGpuProcess ||
@@ -357,7 +361,7 @@ bool HandleVersionSwitches(const base::CommandLine& command_line) {
 
   if (command_line.HasSwitch(switches::kVersion)) {
     printf("%s %s %s\n", version_info::GetProductName().c_str(),
-           version_info::GetVersionNumber().c_str(),
+           version_info::GetUOSVersionNumber().c_str(),
            chrome::GetChannelName().c_str());
     return true;
   }
@@ -1220,6 +1224,14 @@ ChromeMainDelegate::CreateContentBrowserClient() {
 #endif
 }
 
+content::ContentPluginClient* ChromeMainDelegate::CreateContentPluginClient() {
+#if defined(CHROME_MULTIPLE_DLL_BROWSER)
+  return NULL;
+#else
+  return g_chrome_content_plugin_client.Pointer();
+#endif
+}
+
 content::ContentGpuClient* ChromeMainDelegate::CreateContentGpuClient() {
 #if defined(CHROME_MULTIPLE_DLL_BROWSER)
   return nullptr;
