@@ -39,6 +39,7 @@
 
 #include "uos/dbus_thread_manager.h"
 #include "uos/database/database_thread_manager.h"
+#include "uos/customize_new_tabs/newtabs_thread_manager.h"
 
 ChromeBrowserMainPartsLinux::ChromeBrowserMainPartsLinux(
     const content::MainFunctionParams& parameters,
@@ -115,6 +116,8 @@ void ChromeBrowserMainPartsLinux::PostMainMessageLoopStart() {
   
   // modify by xiaohuyang, Initialization of the thread management class of the database. 2021/3/2
   uos::database::DatabaseThreadManager::Initialize();
+
+  uos::customize_tab::CustomizeNewTabsThreadManager::Initialize();
 #endif
 
   ChromeBrowserMainPartsPosix::PostMainMessageLoopStart();
@@ -131,6 +134,8 @@ void ChromeBrowserMainPartsLinux::PostDestroyThreads() {
 
   bluez::BluezDBusManager::Shutdown();
   bluez::BluezDBusThreadManager::Shutdown();
+
+  uos::customize_tab::CustomizeNewTabsThreadManager::Shutdown();
 #endif
 
   ChromeBrowserMainPartsPosix::PostDestroyThreads();
