@@ -25,12 +25,16 @@
 #include "chrome/browser/download/download_stats.h"
 #include "chrome/browser/download/offline_item_utils.h"
 #include "chrome/browser/profiles/profile.h"
+#include "chrome/browser/safe_browsing/download_protection/deep_scanning_request.h"
+#include "chrome/browser/safe_browsing/download_protection/download_feedback_service.h"
 #include "chrome/grit/chromium_strings.h"
 #include "chrome/grit/generated_resources.h"
 #include "components/download/public/common/download_danger_type.h"
 #include "components/download/public/common/download_interrupt_reasons.h"
 #include "components/download/public/common/download_item.h"
 #include "components/safe_browsing/buildflags.h"
+#include "components/safe_browsing/core/file_type_policies.h"
+#include "components/safe_browsing/core/proto/download_file_types.pb.h"
 #include "content/public/browser/download_item_utils.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/l10n/time_format.h"
@@ -43,6 +47,7 @@
 using base::TimeDelta;
 using download::DownloadItem;
 using MixedContentStatus = download::DownloadItem::MixedContentStatus;
+using safe_browsing::DownloadFileType;
 
 namespace {
 
@@ -72,6 +77,10 @@ class DownloadItemModelData : public base::SupportsUserData::Data {
   // for the file type.
   bool should_prefer_opening_in_browser_;
 
+  // Danger level of the file determined based on the file type and whether
+  // there was a user action associated with the download.
+  DownloadFileType::DangerLevel danger_level_;
+
   // Whether the download is currently being revived.
   bool is_being_revived_;
 
@@ -107,6 +116,7 @@ DownloadItemModelData::DownloadItemModelData()
     : should_show_in_shelf_(true),
       was_ui_notified_(false),
       should_prefer_opening_in_browser_(false),
+      danger_level_(DownloadFileType::NOT_DANGEROUS),
       is_being_revived_(false) {}
 
 } // namespace
@@ -286,7 +296,14 @@ bool DownloadItemModel::IsMixedContent() const {
 }
 
 bool DownloadItemModel::ShouldAllowDownloadFeedback() const {
+#if BUILDFLAG(FULL_SAFE_BROWSING)
+  if (!IsDangerous())
+    return false;
+  return safe_browsing::DownloadFeedbackService::IsEnabledForDownload(
+      *download_);
+#else
   return false;
+#endif
 }
 
 bool DownloadItemModel::ShouldRemoveFromShelfWhenComplete() const {
@@ -383,6 +400,17 @@ void DownloadItemModel::SetShouldPreferOpeningInBrowser(bool preference) {
   data->should_prefer_opening_in_browser_ = preference;
 }
 
+DownloadFileType::DangerLevel DownloadItemModel::GetDangerLevel() const {
+  const DownloadItemModelData* data = DownloadItemModelData::Get(download_);
+  return data ? data->danger_level_ : DownloadFileType::NOT_DANGEROUS;
+}
+
+void DownloadItemModel::SetDangerLevel(
+    DownloadFileType::DangerLevel danger_level) {
+  DownloadItemModelData* data = DownloadItemModelData::GetOrCreate(download_);
+  data->danger_level_ = danger_level;
+}
+
 download::DownloadItem::MixedContentStatus
 DownloadItemModel::GetMixedContentStatus() const {
   return download_->GetMixedContentStatus();
@@ -535,6 +563,9 @@ bool DownloadItemModel::IsCommandEnabled(
       // filename. Don't base an "Always open" decision based on it. Also
       // exclude extensions.
       return download_->CanOpenDownload() &&
+             safe_browsing::FileTypePolicies::GetInstance()
+                 ->IsAllowedToOpenAutomatically(
+                     download_->GetTargetFilePath()) &&
              !download_crx_util::IsExtensionDownload(*download_);
     case DownloadCommands::PAUSE:
       return !download_->IsSavePackageDownload() &&
@@ -692,7 +723,6 @@ void DownloadItemModel::ExecuteCommand(DownloadCommands* download_commands,
       DownloadUIModel::ExecuteCommand(download_commands, command);
       break;
     case DownloadCommands::DEEP_SCAN:
-#if BUILDFLAG(FULL_SAFE_BROWSING)
       safe_browsing::SafeBrowsingService* sb_service =
           g_browser_process->safe_browsing_service();
       if (!sb_service)
@@ -716,7 +746,6 @@ void DownloadItemModel::ExecuteCommand(DownloadCommands* download_commands,
           safe_browsing::DeepScanningRequest::DeepScanTrigger::
               TRIGGER_APP_PROMPT,
           {safe_browsing::DeepScanningRequest::DeepScanType::SCAN_MALWARE});
-#endif
       break;
   }
 }
