@@ -261,6 +261,10 @@ void DownloadPrefs::RegisterProfilePrefs(
   const base::FilePath& default_download_path = GetDefaultDownloadDirectory();
   registry->RegisterFilePathPref(prefs::kDownloadDefaultDirectory,
                                  default_download_path);
+#ifndef OPENSSL_NO_GMTLS
+  registry->RegisterFilePathPref(prefs::kUsbKeyDirectory,
+                                 default_download_path);
+#endif
   registry->RegisterFilePathPref(prefs::kSaveFileDefaultDirectory,
                                  default_download_path);
 #if defined(OS_WIN) || defined(OS_LINUX) || defined(OS_MACOSX)
