@@ -34,6 +34,9 @@
 #include "ui/base/clipboard/scoped_clipboard_writer.h"
 #include "ui/base/l10n/l10n_util.h"
 
+#include "uos/dbus_thread_manager.h"
+#include "uos/dde/dde_password_auth_client.h"
+
 #if defined(OS_WIN)
 #include "chrome/browser/password_manager/password_manager_util_win.h"
 #elif defined(OS_MACOSX)
@@ -310,15 +313,7 @@ bool PasswordsPrivateDelegateImpl::OsReauthCall(
           : kShowPasswordAuthTokenLifetime;
   return auth_token->GetAge() <= auth_token_lifespan;
 #else
-  //return true;
-  auto ret = system("pkexec deepin-password-auth");
-  if (ret == 0) {
-    LOG(INFO) << "true, ret = " << ret;
-    return true;
-    } else {
-      LOG(INFO) << "false, ret = " << ret;
-      return false;
-    }
+  return dbus::uos::DBusThreadManager::Get()->GetDdePasswordAuthClient()->browserCheckAuthorization();
 #endif
 }
 
