@@ -160,6 +160,8 @@ const PrefsUtil::TypedPrefMap& PrefsUtil::GetWhitelistedKeys() {
       settings_api::PrefType::PREF_TYPE_BOOLEAN;
   (*s_whitelist)[bookmarks::prefs::kShowBookmarkBar] =
       settings_api::PrefType::PREF_TYPE_BOOLEAN;
+  (*s_whitelist)[bookmarks::prefs::kShowGM] =
+      settings_api::PrefType::PREF_TYPE_BOOLEAN;
 
 #if defined(OS_LINUX) && !defined(OS_CHROMEOS)
   (*s_whitelist)[::prefs::kUseCustomChromeFrame] =
@@ -212,6 +214,10 @@ const PrefsUtil::TypedPrefMap& PrefsUtil::GetWhitelistedKeys() {
   // Downloads settings.
   (*s_whitelist)[::prefs::kDownloadDefaultDirectory] =
       settings_api::PrefType::PREF_TYPE_STRING;
+#ifndef OPENSSL_NO_GMTLS
+  (*s_whitelist)[::prefs::kUsbKeyDirectory] =
+      settings_api::PrefType::PREF_TYPE_STRING;
+#endif
   (*s_whitelist)[::prefs::kPromptForDownload] =
       settings_api::PrefType::PREF_TYPE_BOOLEAN;
   (*s_whitelist)[drive::prefs::kDisableDrive] =
@@ -655,6 +661,8 @@ const PrefsUtil::TypedPrefMap& PrefsUtil::GetWhitelistedKeys() {
       settings_api::PrefType::PREF_TYPE_BOOLEAN;
   (*s_whitelist)[::prefs::kHardwareAccelerationModeEnabled] =
       settings_api::PrefType::PREF_TYPE_BOOLEAN;
+  (*s_whitelist)[::prefs::kVideoDecodeAccelerationModeEnabled] =
+      settings_api::PrefType::PREF_TYPE_BOOLEAN;
 
   // Import data
   (*s_whitelist)[::prefs::kImportDialogAutofillFormData] =
@@ -692,11 +700,6 @@ const PrefsUtil::TypedPrefMap& PrefsUtil::GetWhitelistedKeys() {
       settings_api::PrefType::PREF_TYPE_BOOLEAN;
 #endif
 
-//add by xiepinze uos theme, , 2020/07/24 start
-    (*s_whitelist)[::prefs::kUosThemeID] =
-        settings_api::PrefType::PREF_TYPE_NUMBER;
-//add by xiepinze uos theme, , 2020/07/24 end
-
   return *s_whitelist;
 }
 
