@@ -49,6 +49,7 @@
 #include "extensions/browser/extension_prefs.h"
 #include "extensions/browser/extension_registry.h"
 #include "extensions/browser/extension_system.h"
+#include "extensions/browser/extension_util.h"
 #include "extensions/browser/install/crx_install_error.h"
 #include "extensions/browser/install/extension_install_ui.h"
 #include "extensions/browser/install_flag.h"
@@ -409,7 +410,8 @@ base::Optional<CrxInstallError> CrxInstaller::AllowInstall(
 
   if (install_cause_ == extension_misc::INSTALL_CAUSE_USER_DOWNLOAD &&
       !is_gallery_install() &&
-      off_store_install_allow_reason_ == OffStoreInstallDisallowed) {
+      off_store_install_allow_reason_ == OffStoreInstallDisallowed &&
+      !extensions::util::IsUOSDefaultExtension(extension->id())) {
     // Don't delete source in this case so that the user can install
     // manually if they want.
     delete_source_ = false;
