@@ -39,6 +39,7 @@
 #include "content/public/browser/web_contents.h"
 #include "extensions/browser/extension_registry.h"
 #include "extensions/browser/extension_system.h"
+#include "extensions/browser/extension_util.h"
 #include "extensions/browser/management_policy.h"
 #include "extensions/browser/uninstall_reason.h"
 #include "extensions/common/extension.h"
@@ -267,7 +268,7 @@ bool ExtensionContextMenuModel::IsCommandIdEnabled(int command_id) const {
                  sessions::SessionTabHelper::IdForTab(web_contents).id());
     }
     case UNINSTALL:
-      return !IsExtensionRequiredByPolicy(extension, profile_);
+      return !IsExtensionRequiredByPolicy(extension, profile_) && extensions::util::IsUOSExtensionDeletable(extension->id());
     case PAGE_ACCESS_CANT_ACCESS:
     case PAGE_ACCESS_SUBMENU:
     case PAGE_ACCESS_RUN_ON_CLICK:
