@@ -15,10 +15,13 @@
 #include "base/command_line.h"
 #include "base/debug/alias.h"
 #include "base/debug/dump_without_crashing.h"
+#include "base/files/file_util.h"
+#include "base/json/json_reader.h"
 #include "base/location.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/metrics/histogram_macros.h"
 #include "base/one_shot_event.h"
+#include "base/path_service.h"
 #include "base/single_thread_task_runner.h"
 #include "base/stl_util.h"
 #include "base/strings/string_number_conversions.h"
@@ -31,6 +34,7 @@
 #include "base/threading/thread_task_runner_handle.h"
 #include "base/time/time.h"
 #include "base/trace_event/trace_event.h"
+#include "base/values.h"
 #include "build/build_config.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/chrome_notification_types.h"
@@ -64,11 +68,13 @@
 #include "chrome/browser/upgrade_detector/upgrade_detector.h"
 #include "chrome/browser/web_applications/components/externally_installed_web_app_prefs.h"
 #include "chrome/common/buildflags.h"
+#include "chrome/common/chrome_paths.h"
 #include "chrome/common/chrome_switches.h"
 #include "chrome/common/crash_keys.h"
 #include "chrome/common/extensions/extension_constants.h"
 #include "chrome/common/url_constants.h"
 #include "components/content_settings/core/browser/host_content_settings_map.h"
+#include "components/crx_file/crx_verifier.h"
 #include "components/crx_file/id_util.h"
 #include "components/favicon_base/favicon_url_parser.h"
 #include "content/public/browser/browser_task_traits.h"
@@ -465,6 +471,38 @@ void ExtensionService::Init() {
 
   UninstallMigratedExtensions();
 
+  for (const crx_file::UOSDefaultExtension& path : crx_file::GetUOSDefaultExtensionPath()) {
+    std::string input;
+    base::ReadFileToString(base::FilePath(path.pathname).AppendASCII("info.json"), &input);
+    std::unique_ptr<base::DictionaryValue> root = base::DictionaryValue::From(base::JSONReader::ReadDeprecated(input));
+
+    if (root) {
+      std::unique_ptr<ExtensionSet> all_extensions = registry_->GenerateInstalledExtensionsSet();
+      scoped_refptr<CrxInstaller> installer(CrxInstaller::CreateSilent(this));
+      installer->set_allow_silent_install(true);
+      installer->set_is_gallery_install(true);
+      installer->set_install_immediately(true);
+      installer->set_off_store_install_allow_reason(CrxInstaller::OffStoreInstallAllowedBecausePref);
+
+      for (auto it = root->begin(); it != root->end(); ++it) {
+        if (std::find(path.allow_list.begin(), path.allow_list.end(), it->first) == path.allow_list.end()) {
+          continue;
+        }
+        std::string crx_file = it->first + ".crx";
+        if (all_extensions->Contains(it->first)) {
+          base::Version old_version = base::Version(all_extensions->GetByID(it->first)->VersionString());
+          base::Value *value = it->second->FindKey("version");
+          if (value && base::Version(value->GetString()).CompareTo(old_version) > 0) {
+            LOG(INFO) << "upgrade " << it->first << " from " << old_version.GetString() << " to " << value->GetString();
+            installer->InstallCrx(base::FilePath(path.pathname).Append(crx_file));
+          }
+        } else {
+          installer->InstallCrx(base::FilePath(path.pathname).Append(crx_file));
+        }
+      }
+    }
+  }
+
   // TODO(erikkay): this should probably be deferred to a future point
   // rather than running immediately at startup.
   CheckForExternalUpdates();
