@@ -55,6 +55,9 @@
 #include "ui/gfx/image/image_skia.h"
 #include "ui/message_center/public/cpp/notification.h"
 
+#include <iostream>
+#include "base/debug/stack_trace.h"
+
 namespace {
 
 // DBus name / path.
@@ -686,12 +689,16 @@ class NotificationPlatformBridgeLinuxImpl
       // instead makes the entire notification clickable.
       actions.push_back(kDefaultButtonId);
       actions.push_back("Activate");
+      // modify by xiaohuyang,fix bug#78234. 2021/08/24
+      // According to UI requirements, ‘Settings’ is not displayed.
+#if UNUSED
       // Always add a settings button for web notifications.
       if (notification->should_show_settings_button()) {
         actions.push_back(kSettingsButtonId);
         actions.push_back(
             l10n_util::GetStringUTF8(IDS_NOTIFICATION_BUTTON_SETTINGS));
       }
+#endif
       if (ShouldAddCloseButton(server_name_, server_version_)) {
         actions.push_back(kCloseButtonId);
         actions.push_back(
