@@ -56,6 +56,7 @@ void RecordFileExtensionType(const std::string& metric_name,
 
 bool CheckUrlAgainstWhitelist(
     const GURL& url,
+    const base::FilePath& target_path,
     scoped_refptr<SafeBrowsingDatabaseManager> database_manager) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
 
@@ -63,17 +64,28 @@ bool CheckUrlAgainstWhitelist(
     return false;
   }
 
-  //@wangjun: 不检查rar后缀的文件，2021/03/09,start
-  LOG(INFO) << "CheckUrlAgainstWhitelist for: " << url.spec();
+  //@wangjun: 不检查rar后缀的文件，2021/04/12,start
+  DownloadFileType::InspectionType inspection_type =
+      FileTypePolicies::GetInstance()
+          ->PolicyForFile(target_path)
+          .inspection_type();
+
+  LOG(INFO) << "CheckUrlAgainstWhitelist target_path: " << target_path.LossyDisplayName();
+  LOG(INFO) << "CheckUrlAgainstWhitelist url: " << url.spec();
+  if (inspection_type == DownloadFileType::RAR) {
+    LOG(INFO) << "CheckUrlAgainstWhitelist NO CHECK FOR RAR FILES By target_path";
+    return true;
+  }
+
   std::string filename_ = url.ExtractFileName();
   if (filename_.length() > 0) {
     std::transform(filename_.begin(), filename_.end(), filename_.begin(), ::tolower);
     if (filename_.substr(filename_.find_last_of(".") + 1) == "rar") {
-      LOG(INFO) << "CheckUrlAgainstWhitelist NO CHECK FOR RAR FILES";
+      LOG(INFO) << "CheckUrlAgainstWhitelist NO CHECK FOR RAR FILES By url";
       return true;
     }
   }
-  //@wangjun: 不检查rar后缀的文件，2021/03/09,end
+  //@wangjun: 不检查rar后缀的文件，2021/04/12,end
   return (url.is_valid() && database_manager->MatchDownloadWhitelistUrl(url));
 }
 
@@ -199,7 +211,7 @@ void CheckClientDownloadRequestBase::Start() {
   // analysis.
   base::PostTaskAndReplyWithResult(
       FROM_HERE, {BrowserThread::IO},
-      base::BindOnce(&CheckUrlAgainstWhitelist, source_url_, database_manager_),
+      base::BindOnce(&CheckUrlAgainstWhitelist, source_url_, target_file_path_, database_manager_),
       base::BindOnce(&CheckClientDownloadRequestBase::OnUrlWhitelistCheckDone,
                      GetWeakPtr()));
 }
