@@ -138,6 +138,9 @@ const struct Resource{
     {"images/ntp_default_favicon.png", IDR_NTP_DEFAULT_FAVICON, "image/png"},
     {"local-ntp.css", IDR_LOCAL_NTP_CSS, "text/css"},
     {"local-ntp.js", IDR_LOCAL_NTP_JS, "application/javascript"},
+    {"plugins.html", IDR_UOS_PLUGINS_HTML, "text/html"},
+    {"plugins.js", IDR_UOS_PLUGINS_JS, "application/javascript"},
+    {"plugins.css", IDR_UOS_PLUGINS_CSS, "text/css"},
     {"utils.js", IDR_LOCAL_NTP_UTILS_JS, "application/javascript"},
     {"voice.css", IDR_LOCAL_NTP_VOICE_CSS, "text/css"},
     {"voice.js", IDR_LOCAL_NTP_VOICE_JS, "application/javascript"},
