@@ -436,6 +436,9 @@ std::string GetProgramClassClass() {
 }
 
 std::string GetIconName() {
+  // add by hwb fix [67176] start  
+  return "org.deepin.browser";
+  // add by hwb fix [67176] end
 #if BUILDFLAG(GOOGLE_CHROME_BRANDING)
   return "google-chrome";
 #else  // BUILDFLAG(CHROMIUM_BRANDING)
@@ -466,10 +469,12 @@ bool GetExistingShortcutContents(base::Environment* env,
 
 base::FilePath GetWebShortcutFilename(const GURL& url) {
   // Use a prefix, because xdg-desktop-menu requires it.
-
+  // add by hwb fix [67176] start  
+  // std::string filename =
+  //    std::string(chrome::kBrowserProcessExecutableName) + "-" + url.spec();
   std::string filename =
-     std::string(chrome::kBrowserProcessExecutableName) + "-" + url.spec();
-
+     std::string(chrome::kUOSBrowserProcessExecutableName) + "-" + url.spec();
+  // add by hwb fix [67176] end       
   base::i18n::ReplaceIllegalCharactersInPath(&filename, '_');
 
   base::FilePath desktop_path;
@@ -497,7 +502,10 @@ std::vector<base::FilePath> GetExistingProfileShortcutFilenames(
                                                 base::BlockingType::MAY_BLOCK);
 
   // Use a prefix, because xdg-desktop-menu requires it.
-  std::string prefix(chrome::kBrowserProcessExecutableName);
+  // add by hwb fix [67176] START  
+  // std::string prefix(chrome::kBrowserProcessExecutableName);
+  std::string prefix(chrome::kUOSBrowserProcessExecutableName);
+  // add by hwb fix [67176] end  
   prefix.append("-");
   std::string suffix("-");
   suffix.append(profile_path.BaseName().value());
