@@ -627,7 +627,11 @@ base::Optional<ThemeHelper::OmniboxColor> ThemeHelper::GetOmniboxColorImpl(
           {dark ? gfx::kGoogleGrey100 : SkColorSetA(gfx::kGoogleGrey900, 0x24),
            false}};
     case TP::COLOR_OMNIBOX_TEXT_DIMMED:
+#if UNUSE
       return blend_with_clamped_contrast(bg_hovered_color());
+#else
+      return fg;
+#endif
     case TP::COLOR_OMNIBOX_RESULTS_TEXT_DIMMED:
       return blend_with_clamped_contrast(results_bg_hovered_color());
     case TP::COLOR_OMNIBOX_RESULTS_TEXT_DIMMED_SELECTED:
@@ -654,13 +658,17 @@ base::Optional<ThemeHelper::OmniboxColor> ThemeHelper::GetOmniboxColorImpl(
       return dark ? blend_toward_max_contrast(fg, 0x18)
                   : security_chip_color(derive_default_icon_color(fg));
     case TP::COLOR_OMNIBOX_SECURITY_CHIP_DANGEROUS:
-    // modify by fangzhouyang, Use same color in both dark and light theme, 2021/3/18 --start
+    // modify by fangzhouyang, Use same color in both dark and light theme, 2021/3/29 --start
     #if 0
       return dark ? blend_toward_max_contrast(fg, 0x18)
                   : security_chip_color({gfx::kGoogleRed600, false});
     #endif
-      return security_chip_color({gfx::kGoogleRed600, false});
-    // modify by fangzhouyang, Use same color in both dark and light theme, 2021/3/18 --end
+      if (dark){
+        return {{SkColorSetRGB(0x9A, 0x2F, 0x2F), false}};
+      } else {
+        return security_chip_color({gfx::kGoogleRed600, false});
+      }
+    // modify by fangzhouyang, Use same color in both dark and light theme, 2021/3/29 --end
     default:
       return base::nullopt;
   }
