@@ -68,7 +68,12 @@
 #include "printing/buildflags/buildflags.h"
 #include "ui/events/keycodes/keyboard_codes.h"
 
-//wangfeng, add, 2021/01/14
+// GMTLS
+#ifndef OPENSSL_NO_GMTLS
+#include "net/ssl/openssl_ssl_util.h"
+#include "content/public/browser/browsing_data_remover.h"
+#endif
+
 #include "uos/dde/dde_manual_util.h"
 
 #include "uos/dbus_thread_manager.h"
@@ -175,6 +180,13 @@ BrowserCommandController::BrowserCommandController(Browser* browser)
       base::Bind(&BrowserCommandController::UpdateCommandsForBookmarkBar,
                  base::Unretained(this)));
 
+#ifndef OPENSSL_NO_GMTLS
+  profile_pref_registrar_.Add(
+      bookmarks::prefs::kShowGM,
+      base::Bind(&BrowserCommandController::UpdateCommandsForGM,
+                 base::Unretained(this)));
+#endif
+
   profile_pref_registrar_.Add(
       prefs::kIncognitoModeAvailability,
       base::Bind(
@@ -1405,7 +1417,24 @@ void BrowserCommandController::UpdateCommandsForBookmarkBar() {
                                      bookmarks::prefs::kShowBookmarkBar) &&
                                  IsShowingMainUI());
 }
+#ifndef OPENSSL_NO_GMTLS
+void BrowserCommandController::UpdateCommandsForGM() {
+  bool bvalue = profile()->GetPrefs()->GetBoolean(bookmarks::prefs::kShowGM);
+  if(bvalue){
+    net::SetSSLGmMode(1);
+  }
+  else{
+    net::SetSSLGmMode(0);
+  }
 
+  //国密开关切换 需要清理下cache 防止下次从cache打开国密网站
+  content::BrowsingDataRemover* remover =
+    content::BrowserContext::GetBrowsingDataRemover(browser_->profile());
+  remover->Remove(base::Time::Min(), base::Time::Max(),
+                  content::BrowsingDataRemover::DATA_TYPE_CACHE,
+                  content::BrowsingDataRemover::ORIGIN_TYPE_UNPROTECTED_WEB);
+}
+#endif
 //add by xiepinze uos theme, 2020/07/24 start
 void BrowserCommandController::UpdateCommandsForUosTheme() {
   if (is_locked_fullscreen_)
@@ -1499,6 +1528,12 @@ void BrowserCommandController::UpdateCommandsForFullscreenMode() {
   UpdateCommandsForUosTheme();
   //add by xiepinze uos theme, 2020/07/24 end
 
+// GMTLS
+#ifndef OPENSSL_NO_GMTLS	
+  bool bvalue = profile()->GetPrefs()->GetBoolean(bookmarks::prefs::kShowGM);
+  net::SetSSLGmMode(bvalue?1:0);
+#endif
+
   UpdateCommandsForIncognitoAvailability();
   UpdateCommandsForHostedAppAvailability();
 }
