@@ -134,8 +134,10 @@ void RegisterBrowserUserPrefs(user_prefs::PrefRegistrySyncable* registry) {
   registry->RegisterBooleanPref(prefs::kAllowPopupsDuringPageUnload, false);
   registry->RegisterBooleanPref(prefs::kUserFeedbackAllowed, true);
   registry->RegisterBooleanPref(prefs::kAllowSyncXHRInPageDismissal, false);
+  //modify by hanll,显示checkbox内容, 2021/03/22, start
   registry->RegisterBooleanPref(
-      prefs::kExternalProtocolDialogShowAlwaysOpenCheckbox, false);
+      prefs::kExternalProtocolDialogShowAlwaysOpenCheckbox, true);
+  //modify by hanll,显示checkbox内容, 2021/03/22, end
   registry->RegisterBooleanPref(prefs::kScreenCaptureAllowed, true);
 
   //add by xiepinze, add page zoom submenu, 2020/08/03, start
