@@ -991,7 +991,8 @@ void AppMenuModel::Build() {
 // Chromium builds.
 
 //add by xiepinze uos theme, 2020/07/24 start
-  if (!browser_->profile()->IsGuestSession()) {
+  const char* xdg_session_type = getenv("XDG_SESSION_TYPE");
+  if ((!xdg_session_type || strncmp(xdg_session_type, "wayland", 7) != 0) && !browser_->profile()->IsGuestSession()) {
     uos_theme_menu_model_ = std::make_unique<UosThemeMenuModel>(this, browser_);
     AddSubMenuWithStringId(IDC_UOS_THEME, IDS_UOS_THEME_MENU, uos_theme_menu_model_.get());
   }
