@@ -1601,6 +1601,8 @@ void BookmarkBarView::ConfigureButton(const BookmarkNode* node,
     // code in the tabstrip.
     bool themify_icon = node->url().SchemeIs(content::kChromeUIScheme);
     gfx::ImageSkia favicon = model_->GetFavicon(node).AsImageSkia();
+    // modify by fangzhouyang, Use theme color when favicon is null, 2021/4/1 --start
+    SkColor iconColorMask = SkColorSetRGB(0x00, 0x81, 0xFF);
     if (favicon.isNull()) {
       if (ui::TouchUiController::Get()->touch_ui() && GetThemeProvider()) {
         // This favicon currently does not match the default favicon icon used
@@ -1612,6 +1614,8 @@ void BookmarkBarView::ConfigureButton(const BookmarkNode* node,
             gfx::CreateVectorIcon(kDefaultTouchFaviconMaskIcon, SK_ColorBLACK);
         favicon = gfx::ImageSkiaOperations::CreateMaskedImage(icon, mask);
       } else {
+        iconColorMask = tp->GetColor(ThemeProperties::COLOR_TOOLBAR_BUTTON_ICON);
+        // modify by fangzhouyang, Use theme color when favicon is null, 2021/4/1 --start
         favicon = favicon::GetDefaultFavicon().AsImageSkia();
       }
       themify_icon = true;
@@ -1624,7 +1628,7 @@ void BookmarkBarView::ConfigureButton(const BookmarkNode* node,
           #if 0
           favicon, tp->GetColor(ThemeProperties::COLOR_TOOLBAR_BUTTON_ICON));
           #endif
-          favicon, SkColorSetRGB(0x00, 0x81, 0xFF));
+          favicon, iconColorMask);
           // modify by fangzhouyang, Use same color in both dark and light theme, 2021/3/18 --end
     }
 
