@@ -39,6 +39,10 @@
 #include "chrome/browser/ui/views/sync/dice_bubble_sync_promo_view.h"
 #endif
 
+#if defined(USE_UNIONTECH_NPAPI)
+#include "chrome/browser/ui/views/frame/browser_view.h"
+#endif
+
 #include "uos/dde/dde_appearance_theme_client.h"
 #include "uos/dbus_thread_manager.h"
 
@@ -99,8 +103,27 @@ views::Widget* BookmarkBubbleView::ShowBubble(
   }
   if (highlighted_button)
     bookmark_bubble_->SetHighlightedButton(highlighted_button);
+
+#if defined(USE_UNIONTECH_NPAPI)
+  views::View *ancestor = anchor_view->GetAncestorWithClassName("BrowserView");
+  DCHECK(ancestor);
+  BrowserView* browser_view = static_cast<BrowserView* > (ancestor);
+
+  std::set<views::NpapiPluginMaskObserver*> set;
+  if (browser_view) {
+    set.insert(browser_view->GetNpapiPluginMaskObserver(bookmark_bubble_->GetWidget()));
+    for (auto* observer_ : browser_view->GetNpapiPluginMaskObserverForChildFrame(bookmark_bubble_->GetWidget())) {
+      if (observer_) {
+        set.insert(observer_);
+      }
+    }
+  }
+  views::Widget* bubble_widget = views::BubbleDialogDelegateView::CreateBubble(bookmark_bubble_, set);
+#else
   views::Widget* bubble_widget =
       views::BubbleDialogDelegateView::CreateBubble(bookmark_bubble_);
+#endif
+
   bubble_widget->Show();
   // Select the entire title textfield contents when the bubble is first shown.
   bookmark_bubble_->name_field_->SelectAll(true);
