@@ -44,6 +44,11 @@
 #include "chrome/grit/theme_resources.h"
 #include "components/bookmarks/browser/bookmark_utils.h"
 
+#ifdef USE_UNIONTECH_NPAPI
+#include "chrome/browser/ui/views/frame/browser_view.h"
+#include "ui/aura/window.h"
+#endif
+
 using bookmarks::BookmarkExpandedStateTracker;
 using bookmarks::BookmarkModel;
 using bookmarks::BookmarkNode;
@@ -247,6 +252,21 @@ void BookmarkEditorView::ExecuteCommand(int command_id, int event_flags) {
 
 void BookmarkEditorView::Show(gfx::NativeWindow parent) {
   constrained_window::CreateBrowserModalDialogViews(this, parent);
+
+#ifdef USE_UNIONTECH_NPAPI
+  BrowserView *browser_view = (BrowserView *)(parent->GetNativeWindowProperty("__BROWSER_VIEW__"));
+  if (browser_view) {
+    GetWidget()->GetNpapiPuginMask()->AddObserver(
+        browser_view->GetNpapiPluginMaskObserver(GetWidget()));
+
+    for (auto* observer_ : browser_view->GetNpapiPluginMaskObserverForChildFrame(GetWidget())) {
+      if (observer_) {
+        GetWidget()->GetNpapiPuginMask()->AddObserver(observer_);
+      }
+    }
+  }
+#endif
+
   UserInputChanged();
   if (show_tree_ && bb_model_->loaded())
     ExpandAndSelect();
