@@ -340,6 +340,22 @@ gfx::Size CollectedCookiesViews::GetMinimumSize() const {
   return gfx::Size(0, View::GetMinimumSize().height());
 }
 
+// modify by xiaohuyang, Only used to set the text color when theme changed. 2021/2/19  --start
+void CollectedCookiesViews::OnThemeChanged() {
+  views::View::OnThemeChanged();
+
+  SkColor text_color;
+  if(GetNativeTheme() && GetNativeTheme()->ShouldUseDarkColors()) {
+    text_color = SK_ColorWHITE;
+  } else {
+    text_color = SkColorSetRGB(65, 77, 104);
+  }
+  block_allowed_button_->SetEnabledTextColors(text_color);
+  allow_blocked_button_->SetEnabledTextColors(text_color);
+  for_session_blocked_button_->SetEnabledTextColors(text_color);
+}
+// modify by xiaohuyang, Only used to set the text color when theme changed. 2021/2/19  --end
+
 ////////////////////////////////////////////////////////////////////////////////
 // CollectedCookiesViews, private:
 
@@ -536,12 +552,12 @@ std::unique_ptr<views::View> CollectedCookiesViews::CreateButtonsPane() {
             this, l10n_util::GetStringUTF16(IDS_COOKIES_REMOVE_LABEL));
     StartNewButtonColumnSet(layout, 0);
 
-    block_allowed_button->SetTextColor(views::Button::STATE_NORMAL, SkColorSetRGB(65, 77, 104));
-    block_allowed_button->SetTextColor(views::Button::STATE_HOVERED, SkColorSetRGB(65, 77, 104));
-    block_allowed_button->SetTextColor(views::Button::STATE_PRESSED, SkColorSetRGB(65, 77, 104));
-    delete_allowed_button->SetTextColor(views::Button::STATE_NORMAL, SkColorSetRGB(65, 77, 104));
-    delete_allowed_button->SetTextColor(views::Button::STATE_HOVERED, SkColorSetRGB(65, 77, 104));
-    delete_allowed_button->SetTextColor(views::Button::STATE_PRESSED, SkColorSetRGB(65, 77, 104));
+    // modify by xiaohuyang, Set the text color and preferred size for the button. 2021/2/19
+#if 1
+    block_allowed_button->SetPreferredSize(gfx::Size(80, 36));
+    delete_allowed_button->SetPreferredSize(gfx::Size(80, 36));
+    delete_allowed_button->SetEnabledTextColors(SkColorSetRGB(255, 87, 54));
+#endif
 
     block_allowed_button_ = layout->AddView(std::move(block_allowed_button));
     delete_allowed_button_ = layout->AddView(std::move(delete_allowed_button));
@@ -564,13 +580,12 @@ std::unique_ptr<views::View> CollectedCookiesViews::CreateButtonsPane() {
             this, l10n_util::GetStringUTF16(
                       IDS_COLLECTED_COOKIES_SESSION_ONLY_BUTTON));
     StartNewButtonColumnSet(layout, 0);
-
-    allow_blocked_button->SetTextColor(views::Button::STATE_NORMAL, SkColorSetRGB(65, 77, 104));
-    allow_blocked_button->SetTextColor(views::Button::STATE_HOVERED, SkColorSetRGB(65, 77, 104));
-    allow_blocked_button->SetTextColor(views::Button::STATE_PRESSED, SkColorSetRGB(65, 77, 104));
-    for_session_blocked_button->SetTextColor(views::Button::STATE_NORMAL, SkColorSetRGB(65, 77, 104));
-    for_session_blocked_button->SetTextColor(views::Button::STATE_HOVERED, SkColorSetRGB(65, 77, 104));
-    for_session_blocked_button->SetTextColor(views::Button::STATE_PRESSED, SkColorSetRGB(65, 77, 104));
+    
+    // modify by xiaohuyang, Set the preferred size for the button. 2021/2/19
+#if 1 
+    allow_blocked_button->SetPreferredSize(gfx::Size(80, 36));
+    for_session_blocked_button->SetPreferredSize(gfx::Size(120, 36));
+#endif
 
     allow_blocked_button_ = layout->AddView(std::move(allow_blocked_button));
     for_session_blocked_button_ =
