@@ -47,15 +47,16 @@
 #include "ui/views/layout/box_layout.h"
 #include "ui/views/layout/grid_layout.h"
 #include "ui/views/native_cursor.h"
-
-#include "ui/base/resource/resource_bundle.h"
-#include "chrome/grit/theme_resources.h"
+#include "ui/views/resources/grit/views_resources.h"
 
 namespace {
 
-const gfx::Insets kWindowIconMargins = gfx::Insets(10,10,0,16);
-const gfx::Insets kWindowTitleMargins = gfx::Insets(20, 20, 0, 16);
-const gfx::Insets kWindowTitleMarginsNoContent = gfx::Insets(16, 16, 16, 16);
+// modify by xiaohuyang, fix bug#72015,  2021/05/17
+// Because we set the size and style of the dialog box according to the UI design, 
+// some details need to be adjusted by ourselves, which is not necessarily correct, but it is the most suitable for the moment.
+const gfx::Insets kWindowIconMargins = gfx::Insets(10,16,0,16);
+const gfx::Insets kWindowTitleMargins = gfx::Insets(20, 16, 0, 16);
+const gfx::Insets kWindowTitleMarginsNoContent = gfx::Insets(16, 16, 0, 16);
 
 enum class LayoutRowType {
   DEFAULT,
@@ -255,6 +256,9 @@ void ContentSettingBubbleContents::ListItemContainer::AddItem(
   std::unique_ptr<views::View> item_contents;
   if (item.has_link) {
     auto link = std::make_unique<views::Link>(item.title);
+    // modify by xiaohuyang, fix bug#72015,  2021/05/17
+    link->SetEnabledColor(SkColorSetRGB(0x00, 0x82, 0xFA));
+
     link->SetElideBehavior(gfx::ELIDE_MIDDLE);
     link->SetHorizontalAlignment(gfx::HorizontalAlignment::ALIGN_LEFT);
     link->set_callback(base::BindRepeating(
@@ -315,9 +319,16 @@ void ContentSettingBubbleContents::ListItemContainer::ResetLayout() {
   item_list_column_set->AddColumn(
       views::GridLayout::LEADING, views::GridLayout::FILL,
       views::GridLayout::kFixedSize, views::GridLayout::USE_PREF, 0, 0);
+  // modify by xiaohuyang, fix bug#72015,  2021/05/17
+  // Move the position of the list item to the left to align with other child views
+#if UNUSED
   const int related_control_horizontal_spacing =
       ChromeLayoutProvider::Get()->GetDistanceMetric(
           views::DISTANCE_RELATED_CONTROL_HORIZONTAL);
+#else
+  const int related_control_horizontal_spacing = 0;
+#endif
+  // modify by xiaohuyang, fix bug#72015,  2021/05/17
   item_list_column_set->AddPaddingColumn(views::GridLayout::kFixedSize,
                                          related_control_horizontal_spacing);
   item_list_column_set->AddColumn(views::GridLayout::LEADING,
@@ -467,7 +478,7 @@ bool ContentSettingBubbleContents::ShouldShowCloseButton() const {
 
 //modify by xiaohuyang, Display window icon when window title is empty,  2020/11/30 --start
 gfx::ImageSkia ContentSettingBubbleContents::GetWindowIcon() {
-  return *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_PERMISSION_PROMPT_BUBBLE_VIEW_ICON));
+  return *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_JAVASCRIPT_DIALOG_ICON));
 }
 bool ContentSettingBubbleContents::ShouldShowWindowIcon() const {
   if(!content_setting_bubble_model_ || content_setting_bubble_model_.get()->bubble_content().title.empty())
@@ -479,7 +490,8 @@ bool ContentSettingBubbleContents::ShouldShowWindowIcon() const {
 void ContentSettingBubbleContents::Init() {
   DCHECK(content_setting_bubble_model_);
   const ChromeLayoutProvider* provider = ChromeLayoutProvider::Get();
-
+  
+  // modify by xiaohuyang, fix bug#72015,  2021/05/17
 #if 0
   SetLayoutManager(std::make_unique<views::BoxLayout>(
       views::BoxLayout::Orientation::kVertical, gfx::Insets(),
@@ -502,7 +514,13 @@ void ContentSettingBubbleContents::Init() {
     message_label->SetHorizontalAlignment(gfx::ALIGN_LEFT);
     rows.push_back({std::move(message_label), LayoutRowType::DEFAULT});
   }
-
+  
+  // modify by xiaohuyang, fix bug#72015,  2021/05/17
+  // Because we set the size and style of the dialog box according to the UI design, 
+  // some details need to be adjusted by ourselves, which is not necessarily correct, but it is the most suitable for the moment.
+  int top_margin = margins().top();
+  int bottom_margin = margins().bottom();
+  
   // Layout for the item list (blocked plugins and popups).
   if (!bubble_content.list_items.empty()) {
     auto list_item_container = std::make_unique<ListItemContainer>(this);
@@ -517,6 +535,9 @@ void ContentSettingBubbleContents::Init() {
          bubble_content.list_items) {
       list_item_container_->AddItem(list_item);
     }
+    
+    // modify by xiaohuyang, fix bug#72015,  2021/05/17
+    top_margin = 15;
   }
 
   const ContentSettingBubbleModel::RadioGroup& radio_group =
@@ -560,6 +581,9 @@ void ContentSettingBubbleContents::Init() {
                             base::Unretained(this)));
     custom_link->SetHorizontalAlignment(gfx::ALIGN_LEFT);
     rows.push_back({std::move(custom_link), LayoutRowType::DEFAULT});
+
+    // modify by xiaohuyang, fix bug#72015,  2021/05/17
+    bottom_margin = 0;
   }
 
   if (bubble_content.manage_text_style ==
@@ -568,19 +592,22 @@ void ContentSettingBubbleContents::Init() {
         std::make_unique<views::Checkbox>(bubble_content.manage_text, this);
     manage_checkbox_ = manage_checkbox.get();
     rows.push_back({std::move(manage_checkbox), LayoutRowType::DEFAULT});
+
+    // modify by xiaohuyang, fix bug#72015,  2021/05/17
+    bottom_margin = 0;
   }
 
   // We have to apply the left and right margins manually, because rows using
   // LayoutRowType::FULL_WIDTH need to not have them applied to look correct.
   const int left_margin = margins().left();
   const int right_margin = margins().right();
-  //modify by xiaohuyang, Set the distance between'extra_view' and other views, 2020/10/12  --start
+  //modify by xiaohuyang, Set the distance between child view and title view, extra view. 2020/10/12  --start
 #if 0
   set_margins(gfx::Insets(margins().top(), 0, margins().bottom(), 0));
 #else
-  set_margins(gfx::Insets(0, 4, 10, 0));
+  set_margins(gfx::Insets(top_margin, 0, bottom_margin, 0));
 #endif
-  //modify by xiaohuyang, Set the distance between'extra_view' and other views, 2020/10/12  --end
+  //modify by xiaohuyang, Set the distance between child view and title view, extra view. 2020/10/12  --end
   
   for (LayoutRow& row : rows) {
     if (row.type != LayoutRowType::FULL_WIDTH) {
