@@ -51,6 +51,7 @@
 
 namespace {
 
+// const int kRightColumnWidth = 285;
 const int kRightColumnWidth = 285;
 constexpr gfx::Size kMaxIconSize{43, 43};
 
@@ -310,6 +311,8 @@ void ExtensionInstalledBubbleView::Init() {
   auto dialog_title_label =
         new views::Label(window_title, CONTEXT_BODY_TEXT_LARGE);
   dialog_title_label->SetMultiLine(true);
+  // modify by xiaohuyang, Set size for ‘SetMultiLine’.
+  dialog_title_label->SizeToFit(kRightColumnWidth);
   dialog_title_label->SetHorizontalAlignment(gfx::ALIGN_CENTER);
   dialog_title_label->SetFontList(gfx::FontList().DeriveWithWeight(gfx::Font::Weight::BOLD));
   AddChildView(dialog_title_label);
