@@ -286,8 +286,13 @@ void OpaqueBrowserFrameViewLayout::LayoutWindowControls() {
 
 void OpaqueBrowserFrameViewLayout::LayoutTitleBar() {
   bool use_hidden_icon_location = true;
-
+  // modify by fangzhouyang, modify web app style, 2021/4/2 --start
+#if UNUSED
   int size = delegate_->GetIconSize();
+#else
+  int size = delegate_->GetIconSize() - 2;
+#endif
+  // modify by fangzhouyang, modify web app style, 2021/4/2 --end
   bool should_show_icon = delegate_->ShouldShowWindowIcon() && window_icon_;
   bool should_show_title = delegate_->ShouldShowWindowTitle() && window_title_;
   int icon_y = 0;
