@@ -301,6 +301,12 @@ IntentPickerBubbleView::IntentPickerBubbleView(
       icon_view_(icon_view),
       icon_type_(icon_type),
       initiating_origin_(initiating_origin) {
+
+  //modify by haifengbao, mod The single button color of the pop-up box to gray, 2021/03/15  --start
+  if(icon_type_ == PageActionIconType::kIntentPicker)
+      DialogDelegate::SetDefaultButton(ui::DIALOG_BUTTON_NONE);
+  //modify by haifengbao, mod The single button color of the pop-up box to gray, 2021/03/15  --end
+
   DialogDelegate::SetButtons(
       show_stay_in_chrome_ ? (ui::DIALOG_BUTTON_OK | ui::DIALOG_BUTTON_CANCEL)
                            : ui::DIALOG_BUTTON_OK);
