@@ -85,11 +85,10 @@ JavaScriptTabModalDialogViewViews::JavaScriptTabModalDialogViewViews(
       dialog_callback_(std::move(dialog_callback)),
       dialog_force_closed_callback_(std::move(dialog_force_closed_callback)) {
   // modify by xiaohuyang, Set the single button style of the JS dialog.  2021/2/2
-// #if 1
-//   DialogDelegate::SetDefaultButton(ui::DIALOG_BUTTON_OK);
-// #else
-//   DialogDelegate::SetDefaultButton(ui::DIALOG_BUTTON_NONE);
-// #endif
+  // For specific modifications, view the modifications of lines 99-102
+#if UNUSED
+  DialogDelegate::SetDefaultButton(ui::DIALOG_BUTTON_OK);
+#endif
   const bool is_alert = dialog_type == content::JAVASCRIPT_DIALOG_TYPE_ALERT;
   DialogDelegate::SetButtons(
       // Alerts only have an OK button, no Cancel, because there is no choice
