@@ -591,11 +591,20 @@ void LocationBarView::Layout() {
 
   int location_needed_width = omnibox_view_->GetTextWidth();
   int available_width = entry_width - location_needed_width;
+  // modify by xiaohuyang, handle task#81099.  2021/07/20  --start
+  // Set the cursor in the address bar to center.
+#if UNUSED
   // The bounds must be wide enough for all the decorations to fit, so if
   // |entry_width| is negative, enlarge by the necessary extra space.
   gfx::Rect location_bounds(0, vertical_padding,
                             std::max(width(), width() - entry_width),
                             location_height);
+#else
+  gfx::Rect location_bounds(0, vertical_padding + 3,
+                            std::max(width(), width() - entry_width),
+                            location_height);
+#endif
+  // modify by xiaohuyang, handle task#81099.  2021/07/20  --end
   leading_decorations.LayoutPass3(&location_bounds, &available_width);
   trailing_decorations.LayoutPass3(&location_bounds, &available_width);
 
