@@ -28,6 +28,11 @@
 #include "ui/views/layout/box_layout.h"
 #include "ui/views/widget/widget.h"
 
+#ifdef USE_UNIONTECH_NPAPI
+#include "chrome/browser/ui/views/frame/browser_view.h"
+#include "ui/aura/window.h"
+#endif
+
 class OmniboxPopupContentsView::AutocompletePopupWidget
     : public ThemeCopyingWidget,
       public base::SupportsWeakPtr<AutocompletePopupWidget> {
@@ -50,6 +55,20 @@ class OmniboxPopupContentsView::AutocompletePopupWidget
     params.parent = parent_widget->GetNativeView();
     params.context = parent_widget->GetNativeWindow();
 
+#ifdef USE_UNIONTECH_NPAPI
+    BrowserView *browser_view = (BrowserView *)(parent_widget->GetNativeView()->GetNativeWindowProperty("__BROWSER_VIEW__"));
+    if(browser_view->GetNpapiPluginMaskObserver(this)) {
+      params.npapi_plugin_mask_observers.push_back(
+        browser_view->GetNpapiPluginMaskObserver(this));
+    }
+
+    for (auto* observer_ : browser_view->GetNpapiPluginMaskObserverForChildFrame(this)) {
+      if (observer_) {
+        params.npapi_plugin_mask_observers.push_back(observer_);
+      }
+    }
+#endif
+
     RoundedOmniboxResultsFrame::OnBeforeWidgetInit(&params, this);
 
     Init(std::move(params));
