@@ -103,12 +103,15 @@ OmniboxResultView::OmniboxResultView(
   views::InstallCircleHighlightPathGenerator(remove_suggestion_button_);
   remove_suggestion_button_->SetTooltipText(
       l10n_util::GetStringUTF16(IDS_OMNIBOX_REMOVE_SUGGESTION));
+  // modify by xiaohuyang, fix bug#89652.  2021/08/04
+#if UNUSED
   remove_suggestion_focus_ring_ =
       views::FocusRing::Install(remove_suggestion_button_);
   remove_suggestion_focus_ring_->SetHasFocusPredicate([&](View* view) {
     return view->GetVisible() && IsSelected() &&
            popup_contents_view_->IsButtonSelected();
   });
+#endif
 
   if (OmniboxFieldTrial::IsSuggestionButtonRowEnabled()) {
     button_row_ = AddChildView(std::make_unique<views::View>());
@@ -132,6 +135,11 @@ SkColor OmniboxResultView::GetColor(OmniboxPart part) const {
   return GetOmniboxColor(GetThemeProvider(), part, GetThemeState());
 }
 
+// modify by xiaohuyang, fix bug#89862.  2021/08/04
+SkColor OmniboxResultView::GetColorUOS(OmniboxPart part) const {
+  return GetThemeState() == OmniboxPartState::SELECTED ? SK_ColorWHITE : GetOmniboxColor(GetThemeProvider(), part, GetThemeState());
+}
+
 void OmniboxResultView::SetMatch(const AutocompleteMatch& match) {
   match_ = match.GetMatchWithContentsAndDescriptionPossiblySwapped();
   animation_->Reset();
@@ -185,6 +193,8 @@ void OmniboxResultView::ShowKeyword(bool show_keyword) {
 }
 
 void OmniboxResultView::ApplyThemeAndRefreshIcons(bool force_reapply_styles) {
+  // modify by xiaohuyang, handle task#81099.  2021/07/20
+#if UNUSED
   bool high_contrast =
       GetNativeTheme() && GetNativeTheme()->UsesHighContrastColors();
   // TODO(tapted): Consider using background()->SetNativeControlColor() and
@@ -200,8 +210,11 @@ void OmniboxResultView::ApplyThemeAndRefreshIcons(bool force_reapply_styles) {
   keyword_view_->separator()->ApplyTextColor(OmniboxPart::RESULTS_TEXT_DIMMED);
   if (suggestion_tab_switch_button_->GetVisible())
     suggestion_tab_switch_button_->UpdateBackground();
+  // modify by xiaohuyang, fix bug#89652.  2021/08/04
+#if UNUSED
   if (remove_suggestion_button_->GetVisible())
     remove_suggestion_focus_ring_->SchedulePaint();
+#endif
 
   // Recreate the icons in case the color needs to change.
   // Note: if this is an extension icon or favicon then this can be done in
@@ -232,6 +245,11 @@ void OmniboxResultView::ApplyThemeAndRefreshIcons(bool force_reapply_styles) {
     keyword_view_->description()->ApplyTextColor(
         OmniboxPart::RESULTS_TEXT_DIMMED);
   }
+#else
+  // Set the background and text colors in different states according to UI requirements.
+  // You should pay attention to these fuctions,such as 'OnSelectionStateChanged','UpdateHoverState' and 'OnThemeChanged'.
+  UpdateStyleOfOmniboxResultView(force_reapply_styles);
+#endif
 }
 
 void OmniboxResultView::OnSelectionStateChanged() {
@@ -591,19 +609,10 @@ gfx::Size OmniboxResultView::CalculatePreferredSize() const {
 
 void OmniboxResultView::OnThemeChanged() {
   views::View::OnThemeChanged();
-  //modify by xiaohuyang, Set the style of the ‘OmniboxResultView’ cross button, 2020/10/14  --start
-#if 0
   views::SetImageFromVectorIcon(remove_suggestion_button_,
                                 vector_icons::kCloseRoundedIcon,
                                 GetLayoutConstant(LOCATION_BAR_ICON_SIZE),
                                 GetColor(OmniboxPart::RESULTS_ICON));
-#else
-  views::SetImageFromVectorIcon(remove_suggestion_button_,
-                                vector_icons::kOmniboxResultViewCloseIcon,
-                                GetLayoutConstant(LOCATION_BAR_ICON_SIZE),
-                                GetColor(OmniboxPart::RESULTS_ICON));
-#endif
-  //modify by xiaohuyang, Set the style of the ‘OmniboxResultView’ cross button, 2020/10/14  --end
   ApplyThemeAndRefreshIcons(true);
 }
 
@@ -644,8 +653,25 @@ void OmniboxResultView::EmitSelectedChildrenChangedAccessibilityEvent() {
 // OmniboxResultView, private:
 
 gfx::Image OmniboxResultView::GetIcon() const {
+  // modify by xiaohuyang, handle task#81099.  2021/07/20  --start
+  // Set the icon colors in different states according to UI requirements.
+#if UNUSED
   return popup_contents_view_->GetMatchIcon(
       match_, GetColor(OmniboxPart::RESULTS_ICON));
+#else
+  bool use_dark = 
+      GetNativeTheme() && GetNativeTheme()->ShouldUseDarkColors();
+  SkColor icon_color;
+  if (use_dark || GetThemeState() == OmniboxPartState::SELECTED) {
+    icon_color = gfx::kGoogleGrey100;;
+  } else {
+    icon_color = gfx::kGoogleGrey700;
+  }
+
+  return popup_contents_view_->GetMatchIcon(
+      match_, icon_color);
+#endif
+  // modify by xiaohuyang, handle task#81099.  2021/07/20  --end
 }
 
 void OmniboxResultView::UpdateHoverState() {
@@ -692,3 +718,69 @@ void OmniboxResultView::OnBoundsChanged(const gfx::Rect& previous_bounds) {
 void OmniboxResultView::AnimationProgressed(const gfx::Animation* animation) {
   InvalidateLayout();
 }
+
+// modify by xiaohuyang, handle task#81099.  2021/07/20  --start
+// Set the background and text colors in different states according to UI requirements.
+// The fuction should be excuted after 'SetMatch(Init)', 'OnSelectionStateChanged', 'UpdateHoverState' and 'OnThemeChanged'.
+void OmniboxResultView::UpdateStyleOfOmniboxResultView(bool force_reapply_styles) {
+  bool high_contrast =
+      GetNativeTheme() && GetNativeTheme()->UsesHighContrastColors();
+  bool use_dark = 
+      GetNativeTheme() && GetNativeTheme()->ShouldUseDarkColors();
+
+  SkColor background_color;
+  if (GetThemeState() == OmniboxPartState::SELECTED) {
+    background_color = gfx::kGoogleBlue600;
+  } else if (GetThemeState() == OmniboxPartState::HOVERED && !use_dark) {
+    background_color = gfx::kGoogleGrey300;
+  } else if (GetThemeState() == OmniboxPartState::HOVERED && use_dark) {
+    background_color = gfx::kGoogleGrey800;
+  } else {
+    background_color = SK_ColorWHITE;
+  }
+  //background
+  SetBackground((GetThemeState() == OmniboxPartState::NORMAL && !high_contrast)
+                    ? nullptr
+                    : views::CreateSolidBackground(background_color));
+
+  SkColor text_color;
+  if (use_dark || GetThemeState() == OmniboxPartState::SELECTED) {
+    text_color = gfx::kGoogleGrey100;;
+  } else {
+    text_color = gfx::kGoogleGrey900;
+  }
+
+  //separator
+  suggestion_view_->separator()->ApplyTextColor(text_color);
+  keyword_view_->separator()->ApplyTextColor(text_color);
+
+  //suggestion tab switch button
+  if (suggestion_tab_switch_button_->GetVisible())
+    suggestion_tab_switch_button_->UpdateBackground();
+
+  //icon
+  suggestion_view_->icon()->SetImage(GetIcon().ToImageSkia());
+  keyword_view_->icon()->SetImage(gfx::CreateVectorIcon(
+      omnibox::kKeywordSearchIcon, GetLayoutConstant(LOCATION_BAR_ICON_SIZE),
+      (GetThemeState() == OmniboxPartState::SELECTED || use_dark) ? SK_ColorWHITE : gfx::kGoogleGrey600));
+  
+  //content and description
+  if (high_contrast || force_reapply_styles) {
+    suggestion_view_->content()->ReapplyStyling();
+    suggestion_view_->description()->ReapplyStyling();
+  } else {
+    suggestion_view_->content()->ApplyTextColor(text_color);
+    suggestion_view_->description()->ApplyTextColor(text_color);
+  } 
+  if (keyword_view_->GetVisible()) {
+    keyword_view_->description()->ApplyTextColor(text_color);
+  }
+
+  //remove suggestion button
+  views::SetImageFromVectorIconUOS(remove_suggestion_button_,
+                                vector_icons::kOmniboxResultViewCloseIcon,
+                                GetLayoutConstant(LOCATION_BAR_ICON_SIZE),
+                                (GetThemeState() == OmniboxPartState::SELECTED || use_dark) ? SK_ColorWHITE : gfx::kGoogleGrey600);
+}
+// modify by xiaohuyang, handle task#81099.  2021/07/20  --end
+
