@@ -88,6 +88,10 @@
 #include "chrome/browser/safe_browsing/chrome_password_protection_service.h"
 #endif
 
+#ifdef USE_UNIONTECH_NPAPI
+#include "chrome/browser/ui/browser_finder.h"
+#endif
+
 using bubble_anchor_util::AnchorConfiguration;
 using bubble_anchor_util::GetPageInfoAnchorConfiguration;
 using bubble_anchor_util::GetPageInfoAnchorRect;
@@ -121,7 +125,8 @@ void AddColumnWithSideMargin(views::GridLayout* layout, int margin, int id) {
 
 std::unique_ptr<views::View> CreateSiteSettingsLink(
     const int side_margin,
-    views::ButtonListener* listener) {
+    views::ButtonListener* listener,
+    int resId) {
   const base::string16& tooltip =
       l10n_util::GetStringUTF16(IDS_PAGE_INFO_SITE_SETTINGS_TOOLTIP);
   //modify by xiaohuyang, Set the icon of setting button, 2020/10/22  --start
@@ -133,7 +138,7 @@ std::unique_ptr<views::View> CreateSiteSettingsLink(
       tooltip, base::string16());
 #else    
   return std::make_unique<PageInfoHoverButton>(
-      listener, *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_SETTING_NORMAL_ICON)),
+      listener, *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(resId)),
       IDS_PAGE_INFO_SITE_SETTINGS_LINK, base::string16(),
       PageInfoBubbleView::VIEW_ID_PAGE_INFO_LINK_OR_BUTTON_SITE_SETTINGS,
       tooltip, base::string16());
@@ -440,7 +445,21 @@ InternalPageInfoBubbleView::InternalPageInfoBubbleView(
 
   set_window_title(l10n_util::GetStringUTF16(text));
 
+#ifdef USE_UNIONTECH_NPAPI
+  Browser* _browser = chrome::FindBrowserWithWebContents(web_contents);
+  BrowserView* _browser_view = BrowserView::GetBrowserViewForBrowser(_browser);
+
+  std::set<views::NpapiPluginMaskObserver*> set;
+  set.insert(_browser_view->GetNpapiPluginMaskObserver(GetWidget()));
+  for (auto* observer_ : _browser_view->GetNpapiPluginMaskObserverForChildFrame(GetWidget())) {
+    if (observer_) {
+      set.insert(observer_);
+    }
+  }
+  views::BubbleDialogDelegateView::CreateBubble(this, set);
+#else
   views::BubbleDialogDelegateView::CreateBubble(this);
+#endif
 
   // Use a normal label's style for the title since there is no content.
   views::Label* title_label =
@@ -551,9 +570,17 @@ PageInfoBubbleView::PageInfoBubbleView(
   site_settings_view_ = layout->AddView(CreateSiteSettingsView());
 
   if (!profile->IsGuestSession()) {
+    int resId = IDR_SETTING_NORMAL_ICON;
+    if(View::GetNativeTheme() && GetNativeTheme()->ShouldUseDarkColors()){
+      resId = IDR_SETTING_DARK_ICON;
+    }
+    else{
+      resId = IDR_SETTING_NORMAL_ICON;
+    }
+
     layout->StartRowWithPadding(views::GridLayout::kFixedSize, kColumnId,
                                 views::GridLayout::kFixedSize, 10);
-    layout->AddView(CreateSiteSettingsLink(side_margin, this));
+    layout->AddView(CreateSiteSettingsLink(side_margin, this, resId));
   }
   //modify by xiaohuyang, Adjust window style, margins, fonts, separators, etc, 2020/07/28  --end
 
@@ -562,7 +589,21 @@ PageInfoBubbleView::PageInfoBubbleView(
   page_feature_info_view_ = layout->AddView(std::make_unique<views::View>());
 #endif
 
+#ifdef USE_UNIONTECH_NPAPI
+  Browser* _browser = chrome::FindBrowserWithWebContents(web_contents);
+  BrowserView* _browser_view = BrowserView::GetBrowserViewForBrowser(_browser);
+
+  std::set<views::NpapiPluginMaskObserver*> set;
+  set.insert(_browser_view->GetNpapiPluginMaskObserver(GetWidget()));
+  for (auto* observer_ : _browser_view->GetNpapiPluginMaskObserverForChildFrame(GetWidget())) {
+    if (observer_) {
+      set.insert(observer_);
+    }
+  }
+  views::BubbleDialogDelegateView::CreateBubble(this, set);
+#else
   views::BubbleDialogDelegateView::CreateBubble(this);
+#endif
 
   // CreateBubble() may not set our size synchronously so explicitly set it here
   // before PageInfo updates trigger child layouts.
@@ -611,6 +652,7 @@ void PageInfoBubbleView::OnWidgetDestroying(views::Widget* widget) {
 
 void PageInfoBubbleView::ButtonPressed(views::Button* button,
                                        const ui::Event& event) {
+
   switch (button->GetID()) {
     case PageInfoBubbleView::VIEW_ID_PAGE_INFO_BUTTON_CLOSE:
       GetWidget()->Close();
@@ -690,8 +732,15 @@ void PageInfoBubbleView::SetCookieInfo(const CookieInfoList& cookie_info_list) {
     const gfx::ImageSkia icon =
         PageInfoUI::GetPermissionIcon(info, GetRelatedTextColor());
 #else
-    const gfx::ImageSkia icon =
-        *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_COOKIE_NORMAL_ICON));
+    gfx::ImageSkia icon;
+    if(GetNativeTheme() && GetNativeTheme()->ShouldUseDarkColors())
+    {
+      icon = *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_COOKIE_DARK_ICON));
+    }
+    else
+    {
+      icon = *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_COOKIE_NORMAL_ICON));
+    }
 #endif
     //modify by xiaohuyang, Set the icon of cookie button, 2020/10/22  --end
 
@@ -873,8 +922,14 @@ void PageInfoBubbleView::SetIdentityInfo(const IdentityInfo& identity_info) {
     const gfx::ImageSkia icon =
         PageInfoUI::GetCertificateIcon(GetRelatedTextColor());
 #else
-    const gfx::ImageSkia icon =
-        *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_CERTIFICATE_NORMAL_ICON));
+    gfx::ImageSkia icon;
+    if(GetNativeTheme() && GetNativeTheme()->ShouldUseDarkColors())
+    {
+      icon = *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_CERTIFICATE_DARK_ICON));
+    }
+    else{
+      icon = *(ui::ResourceBundle::GetSharedInstance().GetImageSkiaNamed(IDR_CERTIFICATE_NORMAL_ICON));
+    }
 #endif
     //modify by xiaohuyang, Set the icon of certificate button, 2020/10/22  --end
     const base::string16 secondary_text = l10n_util::GetStringUTF16(
