@@ -52,6 +52,10 @@
 #include "ui/base/resource/resource_bundle.h"
 #include "chrome/grit/theme_resources.h"
 
+#ifdef USE_UNIONTECH_NPAPI
+#include "chrome/browser/ui/views/frame/browser_view.h"
+#endif
+
 namespace {
 
 enum SessionCrashedBubbleHistogramValue {
@@ -120,9 +124,15 @@ class SessionCrashedBubbleView::BrowserRemovalObserver
   DISALLOW_COPY_AND_ASSIGN(BrowserRemovalObserver);
 };
 
+views::Widget* SessionCrashedBubble::widget = nullptr;
+Browser* SessionCrashedBubble::browser_ = nullptr;
+
 // static
 void SessionCrashedBubble::ShowIfNotOffTheRecordProfile(Browser* browser) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
+
+  browser_ = browser;
+
   if (browser->profile()->IsOffTheRecord())
     return;
 
@@ -131,19 +141,24 @@ void SessionCrashedBubble::ShowIfNotOffTheRecordProfile(Browser* browser) {
       std::make_unique<SessionCrashedBubbleView::BrowserRemovalObserver>(
           browser);
 
-  if (DoesSupportConsentCheck()) {
-    base::PostTaskAndReplyWithResult(
-        GoogleUpdateSettings::CollectStatsConsentTaskRunner(), FROM_HERE,
-        base::BindOnce(&GoogleUpdateSettings::GetCollectStatsConsent),
-        base::BindOnce(&SessionCrashedBubbleView::Show,
-                       std::move(browser_observer)));
-  } else {
-    SessionCrashedBubbleView::Show(std::move(browser_observer), false);
-  }
+  widget = SessionCrashedBubbleView::Show(std::move(browser_observer), false);
 }
 
 // static
-void SessionCrashedBubbleView::Show(
+void SessionCrashedBubble::ReplaySessionCrashedBubbleWidget() {
+  BrowserView* _browser_view = BrowserView::GetBrowserViewForBrowser(browser_);
+  widget->GetNpapiPuginMask()->AddObserver(_browser_view->GetNpapiPluginMaskObserver(widget));
+  for (auto* observer_ : _browser_view->GetNpapiPluginMaskObserverForChildFrame(widget)) {
+    if (observer_) {
+      widget->GetNpapiPuginMask()->AddObserver(observer_);
+    }
+  }
+  widget->Hide();
+  widget->Show();
+}
+
+// static
+views::Widget* SessionCrashedBubbleView::Show(
     std::unique_ptr<BrowserRemovalObserver> browser_observer,
     bool uma_opted_in_already) {
   // Determine whether or not the UMA opt-in option should be offered. It is
@@ -158,17 +173,32 @@ void SessionCrashedBubbleView::Show(
 
   if (!browser || !browser->tab_strip_model()->GetActiveWebContents()) {
     RecordBubbleHistogramValue(SESSION_CRASHED_BUBBLE_ERROR);
-    return;
+    return nullptr;
   }
 
   SessionCrashedBubbleView* crash_bubble = new SessionCrashedBubbleView(
       GetSessionCrashedBubbleAnchorView(browser),
       GetSessionCrashedBubbleAnchorRect(browser), browser, offer_uma_optin);
-  views::BubbleDialogDelegateView::CreateBubble(crash_bubble)->Show();
+#ifdef USE_UNIONTECH_NPAPI
+  views::Widget* widget = views::BubbleDialogDelegateView::CreateBubble(crash_bubble);
+  BrowserView* _browser_view = BrowserView::GetBrowserViewForBrowser(browser);
+  widget->GetNpapiPuginMask()->AddObserver(_browser_view->GetNpapiPluginMaskObserver(widget));
+  for (auto* observer_ : _browser_view->GetNpapiPluginMaskObserverForChildFrame(widget)) {
+    if (observer_) {
+      widget->GetNpapiPuginMask()->AddObserver(observer_);
+    }
+  }
+  widget->Show();
+#else
+  views::Widget* widget = views::BubbleDialogDelegateView::CreateBubble(crash_bubble);
+  widget->Show();
+#endif
 
   RecordBubbleHistogramValue(SESSION_CRASHED_BUBBLE_SHOWN);
   if (uma_opted_in_already)
     RecordBubbleHistogramValue(SESSION_CRASHED_BUBBLE_ALREADY_UMA_OPTIN);
+
+  return widget;
 }
 
 ax::mojom::Role SessionCrashedBubbleView::GetAccessibleWindowRole() {
@@ -193,6 +223,13 @@ SessionCrashedBubbleView::SessionCrashedBubbleView(views::View* anchor_view,
        !session_startup_pref.urls.empty())
           ? ui::DIALOG_BUTTON_OK | ui::DIALOG_BUTTON_CANCEL
           : ui::DIALOG_BUTTON_OK);
+  // modify by xiaohuyang, fix bug#88805, 2021/8/9
+  // Force set the background of the separate OK button to gray according to the UI requirements, although it should be blue.
+#if 1
+  if(!(session_startup_pref.type == SessionStartupPref::URLS &&
+       !session_startup_pref.urls.empty()))
+    DialogDelegate::SetDefaultButton(ui::DIALOG_BUTTON_NONE);
+#endif
   DialogDelegate::SetButtonLabel(
       ui::DIALOG_BUTTON_OK,
       l10n_util::GetStringUTF16(IDS_SESSION_CRASHED_VIEW_RESTORE_BUTTON));
@@ -313,8 +350,6 @@ void SessionCrashedBubbleView::Init() {
       margins().width());
   AddChildView(std::move(text_label));
 
-  DialogDelegate::SetDefaultButton(ui::DIALOG_BUTTON_NONE);
-
   if (offer_uma_optin_)
     AddChildView(CreateUmaOptInView());
 
