@@ -11,6 +11,7 @@
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/profiles/profile_manager.h"
 #include "chrome/browser/profiles/profile_window.h"
+#include "chrome/browser/shell_integration_linux.h"
 #include "chrome/browser/task_manager/task_manager_interface.h"
 #include "chrome/browser/task_manager/task_manager_observer.h"
 #include "chrome/browser/ui/browser_dialogs.h"
@@ -79,7 +80,16 @@ task_manager::TaskManagerTableModel* TaskManagerView::Show(Browser* browser) {
   // will open the task manager on the root window for new windows.
   gfx::NativeWindow context =
       browser ? browser->window()->GetNativeWindow() : nullptr;
-  DialogDelegate::CreateDialogWidget(g_task_manager_view, context, nullptr);
+
+  const char* xdg_session_type = getenv("XDG_SESSION_TYPE");
+  if ((!xdg_session_type || strncmp(xdg_session_type, "wayland", 7) != 0)) {
+    DialogDelegate::CreateDialogWidget(g_task_manager_view, context, nullptr);
+  } else {
+    std::string wm_class = shell_integration_linux::GetProgramClassClass();
+    std::string wm_name = shell_integration_linux::GetProgramClassName();
+    DialogDelegate::CreateDialogWidgetForTaskManagerWayland(g_task_manager_view, context, nullptr, wm_class, wm_name);
+  }
+
   g_task_manager_view->InitAlwaysOnTopState();
 
 #if defined(OS_WIN)
