@@ -930,6 +930,10 @@ bool AppMenu::IsCommandEnabled(int command_id) const {
       command_id == IDC_EXTENSIONS_OVERFLOW_MENU)
     return true;
 
+  //fix bug#84781. Disenable clicking on policy info. @xudongxu 2021/06/23
+  if (command_id == IDC_SHOW_MANAGEMENT_PAGE)
+    return false;
+
   const Entry& entry = command_id_to_entry_.find(command_id)->second;
   return entry.first->IsEnabledAt(entry.second);
 }
