@@ -215,12 +215,12 @@ void ToolbarView::Init() {
   std::unique_ptr<media_router::CastToolbarButton> cast;
   if (media_router::MediaRouterEnabled(browser_->profile()))
     cast = media_router::CastToolbarButton::Create(browser_);
-
+#if unused
   std::unique_ptr<MediaToolbarButtonView> media_button;
   if (base::FeatureList::IsEnabled(media::kGlobalMediaControls)) {
     media_button = std::make_unique<MediaToolbarButtonView>(browser_);
   }
-
+#endif
   std::unique_ptr<ToolbarAccountIconContainerView>
       toolbar_account_icon_container;
   //modify by wangjuna, hide google account login button, 2020/07/08 --start
@@ -269,10 +269,10 @@ void ToolbarView::Init() {
 
   if (cast)
     cast_ = AddChildView(std::move(cast));
-
+#if unused
   if (media_button)
     media_button_ = AddChildView(std::move(media_button));
-
+#endif
   if (toolbar_account_icon_container) {
     toolbar_account_icon_container_ =
         AddChildView(std::move(toolbar_account_icon_container));
@@ -352,6 +352,11 @@ void ToolbarView::SetToolbarVisibility(bool visible) {
 void ToolbarView::UpdateCustomTabBarVisibility(bool visible, bool animate) {
   DCHECK_EQ(display_mode_, DisplayMode::CUSTOM_TAB);
 
+  // modify by fangzhouyang, do not show location bar in quick version of IQIYI, 2021/3/22 --start
+  if(visible && (display_mode_ == DisplayMode::CUSTOM_TAB)){
+    return;
+  }
+  // modify by fangzhouyang, do not show location bar in quick version of IQIYI, 2021/3/22 --end
   if (!animate) {
     size_animation_.Reset(visible ? 1.0 : 0.0);
     SetToolbarVisibility(visible);
@@ -930,10 +935,10 @@ void ToolbarView::LoadImages() {
 
   if (cast_)
     cast_->UpdateIcon();
-
+#if unused
   if (media_button_)
     media_button_->UpdateIcon();
-
+#endif
 #if BUILDFLAG(ENABLE_WEBUI_TAB_STRIP)
   if (browser_view_->webui_tab_strip())
     browser_view_->webui_tab_strip()->UpdateButtons();
