@@ -121,10 +121,16 @@ class WebAppToolbarActionsBar : public ToolbarActionsBar {
   DISALLOW_COPY_AND_ASSIGN(WebAppToolbarActionsBar);
 };
 
+// modify by fangzhouyang, modify web app style, 2021/4/2 --start
 int HorizontalPaddingBetweenPageActionsAndAppMenuButtons() {
+#if UNUSED
   return views::LayoutProvider::Get()->GetDistanceMetric(
       views::DISTANCE_RELATED_CONTROL_HORIZONTAL);
+#else
+  return 0;
+#endif
 }
+// modify by fangzhouyang, modify web app style, 2021/4/2 --end
 
 int WebAppFrameRightMargin() {
 #if defined(OS_MACOSX)
